reslr_load function.R/print.reslr_input.R
print.reslr_input.RdIn this function, the reslr input object is printed. This is a high-level summary which provides the number of observations and the number of sites utilised in the dataset.
# S3 method for class 'reslr_input'
print(x, ...)A neat presentation of your input reslr object
data <- NAACproxydata %>% dplyr::filter(Site == "Cedar Island")
reslr_input <- reslr_load(data = data)
print(x = reslr_input)
#> This is a valid reslr input object with 104 observations and 1 site(s).
#> There are 1 proxy site(s) and 0 tide gauge site(s).
#> The age units are; Common Era.
#> Decadally averaged tide gauge data was not included. It is recommended for the ni_gam_decomp model
#> The linear_rate or linear_rate_err was not included. It is required for the ni_gam_decomp model