Learn R Programming

reslr (version 0.1.1)

print.reslr_input: Print a reslr output object which is created from the reslr_load function.

Description

In this function, the reslr input object is printed. This is a high-level summary which provides the number of observations and the number of sites utilised in the dataset.

Usage

# S3 method for reslr_input
print(x, ...)

Value

A neat presentation of your input reslr object

Arguments

x

An object of class reslr_input

...

Other arguments (not supported)

Examples

Run this code
data <- NAACproxydata %>% dplyr::filter(Site == "Cedar Island")
reslr_input <- reslr_load(data = data)
print(x = reslr_input)

Run the code above in your browser using DataLab