print.reslr_input: Print a reslr output object which is created from the reslr_load function.
Description
In this function, the reslr input object is printed. This is a high-level summary which provides the number of observations and the number of sites utilised in the dataset.