Learn R Programming

reslr (version 0.1.1)

print.reslr_output: Print a reslr output object which is created by the reslr_mcmc function.

Description

This will be very high level printing that the user can use to obtain information about the MCMC run using JAGS. The number of iterations and chains used by the user is printed In addition, the type of statistical model is printed.

Usage

# S3 method for reslr_output
print(x, ...)

Value

Returns high level information about the reslr_output object, i.e. the number of iterations and chains used.

Arguments

x

An object of class reslr_output

...

Other arguments (not supported)

Examples

Run this code
# \donttest{
data <- NAACproxydata %>% dplyr::filter(Site == "Cedar Island")
input_data <- reslr_load(data = data)
jags_output <- reslr_mcmc(input_data = input_data, model_type = "eiv_slr_t")
print(x = jags_output)# }

Run the code above in your browser using DataLab